/********************************************************************************
** Form generated from reading UI file 'gdrivepropertiesplugin.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GDRIVEPROPERTIESPLUGIN_H
#define UI_GDRIVEPROPERTIESPLUGIN_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GDrivePropertiesWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *idLabel;
    QLabel *idValue;
    QLabel *descriptionLabel;
    QLabel *descriptionValue;
    QLabel *ownersLabel;
    QLabel *ownersValue;
    QLabel *createdLabel;
    QLabel *createdValue;
    QLabel *modifiedLabel;
    QLabel *modifiedValue;
    QLabel *lastViewedByMeLabel;
    QLabel *lastViewedByMeValue;
    QLabel *versionLabel;
    QLabel *versionValue;
    QLabel *md5Label;
    QLabel *md5Value;
    QLabel *lastModifiedByLabel;
    QLabel *lastModifiedByValue;
    QLabel *sharedWithMeLabel;
    QLabel *sharedWithMeValue;
    QSpacerItem *betweenFormAndButtonsSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *urlOpenButton;
    QPushButton *urlCopyButton;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GDrivePropertiesWidget)
    {
        if (GDrivePropertiesWidget->objectName().isEmpty())
            GDrivePropertiesWidget->setObjectName("GDrivePropertiesWidget");
        GDrivePropertiesWidget->resize(783, 612);
        verticalLayout = new QVBoxLayout(GDrivePropertiesWidget);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFormAlignment(Qt::AlignHCenter|Qt::AlignTop);
        idLabel = new QLabel(GDrivePropertiesWidget);
        idLabel->setObjectName("idLabel");
        idLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        idLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, idLabel);

        idValue = new QLabel(GDrivePropertiesWidget);
        idValue->setObjectName("idValue");
        idValue->setText(QString::fromUtf8("idValue"));
        idValue->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, idValue);

        descriptionLabel = new QLabel(GDrivePropertiesWidget);
        descriptionLabel->setObjectName("descriptionLabel");
        descriptionLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        descriptionLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, descriptionLabel);

        descriptionValue = new QLabel(GDrivePropertiesWidget);
        descriptionValue->setObjectName("descriptionValue");
        descriptionValue->setText(QString::fromUtf8("descriptionValue"));
        descriptionValue->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, descriptionValue);

        ownersLabel = new QLabel(GDrivePropertiesWidget);
        ownersLabel->setObjectName("ownersLabel");
        ownersLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        ownersLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, ownersLabel);

        ownersValue = new QLabel(GDrivePropertiesWidget);
        ownersValue->setObjectName("ownersValue");
        ownersValue->setText(QString::fromUtf8("ownersValue"));
        ownersValue->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, ownersValue);

        createdLabel = new QLabel(GDrivePropertiesWidget);
        createdLabel->setObjectName("createdLabel");
        createdLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        createdLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, createdLabel);

        createdValue = new QLabel(GDrivePropertiesWidget);
        createdValue->setObjectName("createdValue");
        createdValue->setText(QString::fromUtf8("createdValue"));
        createdValue->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, createdValue);

        modifiedLabel = new QLabel(GDrivePropertiesWidget);
        modifiedLabel->setObjectName("modifiedLabel");
        modifiedLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        modifiedLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, modifiedLabel);

        modifiedValue = new QLabel(GDrivePropertiesWidget);
        modifiedValue->setObjectName("modifiedValue");
        modifiedValue->setText(QString::fromUtf8("modifiedValue"));
        modifiedValue->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, modifiedValue);

        lastViewedByMeLabel = new QLabel(GDrivePropertiesWidget);
        lastViewedByMeLabel->setObjectName("lastViewedByMeLabel");
        lastViewedByMeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lastViewedByMeLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, lastViewedByMeLabel);

        lastViewedByMeValue = new QLabel(GDrivePropertiesWidget);
        lastViewedByMeValue->setObjectName("lastViewedByMeValue");
        lastViewedByMeValue->setText(QString::fromUtf8("lastViewedByMeValue"));
        lastViewedByMeValue->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, lastViewedByMeValue);

        versionLabel = new QLabel(GDrivePropertiesWidget);
        versionLabel->setObjectName("versionLabel");
        versionLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        versionLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, versionLabel);

        versionValue = new QLabel(GDrivePropertiesWidget);
        versionValue->setObjectName("versionValue");
        versionValue->setText(QString::fromUtf8("versionValue"));
        versionValue->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, versionValue);

        md5Label = new QLabel(GDrivePropertiesWidget);
        md5Label->setObjectName("md5Label");
        md5Label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        md5Label->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, md5Label);

        md5Value = new QLabel(GDrivePropertiesWidget);
        md5Value->setObjectName("md5Value");
        md5Value->setText(QString::fromUtf8("md5Value"));
        md5Value->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, md5Value);

        lastModifiedByLabel = new QLabel(GDrivePropertiesWidget);
        lastModifiedByLabel->setObjectName("lastModifiedByLabel");
        lastModifiedByLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lastModifiedByLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, lastModifiedByLabel);

        lastModifiedByValue = new QLabel(GDrivePropertiesWidget);
        lastModifiedByValue->setObjectName("lastModifiedByValue");
        lastModifiedByValue->setText(QString::fromUtf8("lastModifiedByValue"));
        lastModifiedByValue->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, lastModifiedByValue);

        sharedWithMeLabel = new QLabel(GDrivePropertiesWidget);
        sharedWithMeLabel->setObjectName("sharedWithMeLabel");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, sharedWithMeLabel);

        sharedWithMeValue = new QLabel(GDrivePropertiesWidget);
        sharedWithMeValue->setObjectName("sharedWithMeValue");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, sharedWithMeValue);


        verticalLayout->addLayout(formLayout);

        betweenFormAndButtonsSpacer = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(betweenFormAndButtonsSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        urlOpenButton = new QPushButton(GDrivePropertiesWidget);
        urlOpenButton->setObjectName("urlOpenButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(urlOpenButton->sizePolicy().hasHeightForWidth());
        urlOpenButton->setSizePolicy(sizePolicy);
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("internet-services");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        urlOpenButton->setIcon(icon);

        horizontalLayout->addWidget(urlOpenButton);

        urlCopyButton = new QPushButton(GDrivePropertiesWidget);
        urlCopyButton->setObjectName("urlCopyButton");
        sizePolicy.setHeightForWidth(urlCopyButton->sizePolicy().hasHeightForWidth());
        urlCopyButton->setSizePolicy(sizePolicy);
        QIcon icon1;
        iconThemeName = QString::fromUtf8("edit-copy");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("../../../kio/src/widgets"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        urlCopyButton->setIcon(icon1);

        horizontalLayout->addWidget(urlCopyButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(GDrivePropertiesWidget);

        QMetaObject::connectSlotsByName(GDrivePropertiesWidget);
    } // setupUi

    void retranslateUi(QWidget *GDrivePropertiesWidget)
    {
        idLabel->setText(tr2i18n("Id:", nullptr));
        descriptionLabel->setText(tr2i18n("Description:", nullptr));
        ownersLabel->setText(tr2i18n("Owners:", nullptr));
        createdLabel->setText(tr2i18n("Created:", nullptr));
        modifiedLabel->setText(tr2i18n("Modified:", nullptr));
        lastViewedByMeLabel->setText(tr2i18n("Last viewed by me:", nullptr));
        versionLabel->setText(tr2i18n("Version:", nullptr));
        md5Label->setText(tr2i18n("MD5 checksum:", nullptr));
        lastModifiedByLabel->setText(tr2i18n("Last modified by:", nullptr));
        sharedWithMeLabel->setText(tr2i18n("Shared with me:", nullptr));
        sharedWithMeValue->setText(QString());
        urlOpenButton->setText(tr2i18n("Open in browser", nullptr));
#if QT_CONFIG(tooltip)
        urlCopyButton->setToolTip(tr2i18n("Click to copy the Google Drive URL to the clipboard.", nullptr));
#endif // QT_CONFIG(tooltip)
        urlCopyButton->setText(tr2i18n("Copy URL to Clipboard", nullptr));
        (void)GDrivePropertiesWidget;
    } // retranslateUi

};

namespace Ui {
    class GDrivePropertiesWidget: public Ui_GDrivePropertiesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GDRIVEPROPERTIESPLUGIN_H

